import { useState, useEffect, useCallback, useMemo, memo } from "react";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { apiRequest } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { useAuth } from "@/hooks/useAuth";
import { useSubscription } from "@/hooks/useSubscription";
import { cn } from "@/lib/utils";
import TarotCard from "./TarotCard";
import AuthModal from "./AuthModal";
import { Button } from "@/components/ui/button";
import { Badge } from "@/components/ui/badge";
import { Dialog, DialogContent, DialogFooter, DialogHeader, DialogTitle, DialogDescription } from "@/components/ui/dialog";
import { ScrollArea } from "@/components/ui/scroll-area";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { motion, AnimatePresence } from "framer-motion";
import { Sparkles, Clock, Info, RefreshCw, Eye, Calendar, HelpCircle } from "lucide-react";
import { tarotCards, cardBackImage, shuffleCards, TarotCard as TarotCardType } from "@/assets/tarotData";
import tarotBackgroundImage from "../assets/images/backgrounds/tarot-background.webp";
import { MarkdownRenderer } from "@/components/ui/markdown-renderer";

// Componente para el fondo optimizado con memoria y menos animaciones
const TarotBackground = memo(function TarotBackground() {
  // Reducido aún más (de 8 a 5) el número de partículas para mejor rendimiento
  // Usamos posiciones y duraciones predefinidas para evitar cálculos aleatorios
  const particles = useMemo(() => [
    { size: 2, x: 15, y: 25, duration: 28, delay: 0 },
    { size: 3, x: 85, y: 30, duration: 32, delay: 2 },
    { size: 1.5, x: 45, y: 60, duration: 30, delay: 5 },
    { size: 2.5, x: 70, y: 75, duration: 25, delay: 8 },
    { size: 2, x: 20, y: 80, duration: 34, delay: 10 }
  ], []);

  return (
    <div 
      className="absolute inset-0 z-0 overflow-hidden bg-cover bg-center bg-no-repeat"
      style={{
        backgroundImage: `url(${tarotBackgroundImage})`,
        opacity: 0.7
      }}
    >
      {/* Overlay de gradiente estático en lugar de animado */}
      <div className="absolute inset-0 bg-gradient-to-b from-indigo-950/70 via-purple-950/60 to-blue-950/70" />
      
      {/* Stardust particles - optimizadas con willChange y menos elementos */}
      <div className="stardust absolute inset-0 pointer-events-none">
        {particles.map((particle, i) => (
          <motion.div
            key={i}
            className="absolute rounded-full"
            style={{
              width: particle.size + 'px',
              height: particle.size + 'px',
              left: particle.x + '%',
              top: particle.y + '%',
              background: `radial-gradient(circle at center, rgba(255, 255, 255, 0.7) 0%, rgba(255, 255, 255, 0.1) 70%, transparent 100%)`,
              willChange: 'transform, opacity', // Optimización de rendimiento
            }}
            initial={{ opacity: 0.2, scale: 0.8 }}
            animate={{
              opacity: [0.2, 0.4, 0.2],
              scale: [0.8, 1.1, 0.8],
            }}
            transition={{
              duration: particle.duration,
              delay: particle.delay,
              repeat: Infinity,
              ease: "easeInOut"
            }}
          />
        ))}
      </div>
    </div>
  );
});

export default function TarotReading() {
  // Estados para manejar las cartas y la lectura
  const [availableCards, setAvailableCards] = useState<TarotCardType[]>([]);
  const [selectedCards, setSelectedCards] = useState<TarotCardType[]>([]);
  const [revealedCards, setRevealedCards] = useState<boolean[]>([false, false, false]);
  const [invertedCards, setInvertedCards] = useState<boolean[]>([false, false, false]);
  const [selectedInvertedCards, setSelectedInvertedCards] = useState<boolean[]>([]);
  const [showResults, setShowResults] = useState(false);
  // Estados para detalles de carta (restaurados)
  const [showCardDetails, setShowCardDetails] = useState(false);
  const [selectedCardDetails, setSelectedCardDetails] = useState<TarotCardType | null>(null);
  const [isCardInverted, setIsCardInverted] = useState(false);
  const [showAuthModal, setShowAuthModal] = useState(false);
  const [readingQuestion, setReadingQuestion] = useState<string>("");
  const [readingResult, setReadingResult] = useState<any>(null);
  const [showReadingDialog, setShowReadingDialog] = useState(false);
  const [isPreviousReading, setIsPreviousReading] = useState(false);
  
  // Hooks para la autenticación, notificaciones, etc.
  const queryClient = useQueryClient();
  const { toast } = useToast();
  const { user } = useAuth();
  const { isPremium } = useSubscription();
  
  // Obtener el historial de lecturas
  const { data: tarotReadingHistory } = useQuery({
    queryKey: ['/api/tarot/readings'],
    enabled: !!user,
  });
  
  // Interfaz para los datos de lecturas disponibles
  interface ReadingsAvailable {
    available: number;
    isPremium: boolean;
    month?: string;
    used?: number;
    limit?: number;
  }
  
  // Para calcular las lecturas mensuales disponibles para usuarios básicos
  const [readingsAvailable, setReadingsAvailable] = useState<number>(8);
  
  // Consultar el contador de lecturas mensuales desde el servidor
  const { data: readingsAvailableData } = useQuery<ReadingsAvailable>({
    queryKey: ['/api/tarot/readings/available'],
    enabled: !!user, // Solo si hay un usuario autenticado
    refetchOnWindowFocus: true,
    refetchOnMount: true,
  });
  
  useEffect(() => {
    // Si tenemos datos del servidor sobre lecturas disponibles
    if (readingsAvailableData) {
      if (readingsAvailableData.isPremium) {
        // Para usuarios premium, mostrar lecturas ilimitadas
        setReadingsAvailable(-1);
      } else {
        // Para usuarios básicos, usar el contador del servidor
        setReadingsAvailable(readingsAvailableData.available);
        
        console.log("Mes actual:", readingsAvailableData.month);
        console.log("Lecturas utilizadas este mes:", readingsAvailableData.used);
        console.log("Límite mensual:", readingsAvailableData.limit);
        console.log("Lecturas disponibles:", readingsAvailableData.available);
      }
    }
    
    // Al cargar el componente, preparamos las cartas iniciales
    if (availableCards.length === 0) {
      prepareNewReading();
    }
  }, [readingsAvailableData, availableCards.length]);
  
  // Preparar una nueva lectura barajando las cartas
  const prepareNewReading = () => {
    setSelectedCards([]);
    setRevealedCards([false, false, false]);
    setSelectedInvertedCards([]);
    
    // Generar aleatoriamente si las cartas estarán invertidas
    // Con una baja probabilidad para las cartas invertidas (10%)
    const newInvertedCards = [false, false, false].map(() => Math.random() < 0.1);
    setInvertedCards(newInvertedCards);
    
    setAvailableCards(shuffleCards(tarotCards).slice(0, 3));
    setShowResults(false);
    setReadingResult(null);
    setReadingQuestion("");
  };
  
  // Seleccionar una carta
  const selectCard = (index: number) => {
    // Permitimos seleccionar una carta incluso si está revelada para poder ver sus detalles
    
    if (selectedCards.length >= 3) {
      toast({
        title: "Máximo 3 cartas",
        description: "Ya has seleccionado el máximo de 3 cartas para tu lectura.",
      });
      return;
    }
    
    // Verificar si el usuario es básico y ya usó todas sus lecturas
    if (!isPremium && readingsAvailable <= 0 && selectedCards.length === 0) {
      toast({
        title: "Límite de lecturas alcanzado",
        description: "Has alcanzado el límite mensual de 8 lecturas para usuarios básicos. Actualiza a Premium para lecturas ilimitadas.",
        variant: "destructive",
      });
      return;
    }
    
    // Seleccionar una carta aleatoria del mazo de arcanos mayores
    // (En este caso usamos la carta que ya tenemos asignada en availableCards)
    const selectedCard = availableCards[index];
    
    // Actualizar la carta como revelada
    const newRevealedCards = [...revealedCards];
    newRevealedCards[index] = true;
    setRevealedCards(newRevealedCards);
    
    // Añadir la carta a las seleccionadas
    setSelectedCards([...selectedCards, selectedCard]);
    
    // Guardar si la carta está invertida
    setSelectedInvertedCards([...selectedInvertedCards, invertedCards[index]]);
    
    // Si se seleccionaron 3 cartas, enviar la lectura
    if (selectedCards.length === 2) {
      setTimeout(() => {
        if (user) {
          submitReading([...selectedCards, selectedCard]);
          setShowReadingDialog(true); // Mostrar diálogo de lectura
        } else {
          setShowAuthModal(true);
        }
      }, 1000); // Dar tiempo para que se complete la animación
    }
  };
  
  // Mutación para enviar la lectura de tarot
  const { mutate: submitTarotReading, isPending } = useMutation({
    mutationFn: async (cards: TarotCardType[]) => {
      // Crear un array con los nombres de las cartas y si están invertidas
      const formattedCards = cards.map((card, index) => {
        // Si la carta está invertida, añadir " (Invertida)" al nombre
        return selectedInvertedCards[index] 
          ? `${card.name} (Invertida)` 
          : card.name;
      });
      
      console.log("Enviando cartas al servidor:", formattedCards);
      
      const data = { 
        cards: formattedCards,
        question: readingQuestion || undefined,
        isPremium // Indicar si es una lectura premium
      };
      const res = await apiRequest("POST", "/api/tarot/reading", data);
      return res.json();
    },
    onSuccess: (data) => {
      // Primero guardar el resultado
      setReadingResult(data);
      
      // Mostrar solo el diálogo principal (no mostrar ambos diálogos a la vez)
      setShowReadingDialog(true);
      setShowResults(false);
      
      // Actualizar lecturas disponibles para usuarios básicos inmediatamente 
      // para la UI mientras se recarga la consulta en segundo plano
      if (!isPremium && readingsAvailable > 0) {
        // El valor se actualizará correctamente cuando se recarguen las lecturas
        // pero aún así actualizamos el estado local para UI inmediata
        setReadingsAvailable(prev => Math.max(0, prev - 1));
        console.log("Lectura realizada. Lecturas restantes (pre-invalidación):", Math.max(0, readingsAvailable - 1));
      }
      
      // Ahora invalidar el caché - esto debería ocurrir después de la actualización de la UI
      // para evitar posibles problemas de carrera
      console.log("Invalidando caché de lecturas y lecturas disponibles");
      
      // Forzar la invalidación de ambas consultas
      queryClient.invalidateQueries({ queryKey: ['/api/tarot/readings'] });
      queryClient.invalidateQueries({ queryKey: ['/api/tarot/readings/available'] });
      
      // Tras 500ms, forzar una recarga explícita de los datos de lecturas disponibles
      setTimeout(() => {
        queryClient.refetchQueries({ queryKey: ['/api/tarot/readings/available'] });
        console.log("Recarga forzada de datos de lecturas disponibles");
      }, 500);
    },
    onError: (error) => {
      console.error("Error al generar lectura de tarot:", error);
      toast({
        title: "Error",
        description: "No se pudo generar la lectura de tarot.",
        variant: "destructive",
      });
    }
  });
  
  const submitReading = (cards: TarotCardType[]) => {
    if (!user) {
      setShowAuthModal(true);
      return;
    }
    
    submitTarotReading(cards);
  };
  
  // Restauramos esta función para ver los detalles de las cartas
  const viewCardDetails = (card: TarotCardType, isInverted: boolean) => {
    setSelectedCardDetails(card);
    setIsCardInverted(isInverted);
    setShowCardDetails(true);
  };
  
  // Función para mostrar la última lectura de tarot
  const showLastReading = () => {
    if (!user) {
      setShowAuthModal(true);
      return;
    }
    
    if (!tarotReadingHistory || (tarotReadingHistory as any[]).length === 0) {
      toast({
        title: "No hay lecturas previas",
        description: "Aún no has realizado ninguna lectura de tarot.",
      });
      return;
    }
    
    // Obtener la última lectura del historial
    const lastReading = (tarotReadingHistory as any[])[0];
    
    // Extraer las cartas del último reading
    const cardNames: string[] = Array.isArray(lastReading.cards) ? lastReading.cards : [];
    
    // Preparar las cartas para mostrar
    const cardObjects = cardNames.map((cardName: string) => {
      // Verificar si la carta está invertida
      const isInverted = cardName.includes("(Invertida)");
      // Obtener el nombre base de la carta
      const baseName = isInverted ? cardName.replace(" (Invertida)", "") : cardName;
      // Encontrar la carta en el mazo de tarot
      const card = tarotCards.find(c => c.name === baseName);
      return card || tarotCards[0]; // Usar la primera carta como fallback
    });
    
    // Obtener info de inversión
    const invertedInfo = cardNames.map((cardName: string) => cardName.includes("(Invertida)"));
    
    // Establecer el estado con los datos de la última lectura
    setReadingResult(lastReading);
    setReadingQuestion(lastReading.question || "");
    setSelectedCards(cardObjects);
    setSelectedInvertedCards(invertedInfo);
    setIsPreviousReading(true);
    setShowReadingDialog(true);
  };
  
  // Animaciones para la aparición de elementos
  const container = {
    hidden: { opacity: 0 },
    show: {
      opacity: 1,
      transition: {
        staggerChildren: 0.1
      }
    }
  };
  
  const item = {
    hidden: { y: 20, opacity: 0 },
    show: { y: 0, opacity: 1 }
  };

  return (
    <section id="tarot" className="py-12 sm:py-16 md:py-20 relative">
      {/* Background image with overlay */}
      <div 
        className="absolute inset-0 z-0" 
        style={{
          backgroundImage: `url(${tarotBackgroundImage})`,
          backgroundSize: 'cover',
          backgroundPosition: 'center',
          backgroundRepeat: 'no-repeat',
          opacity: 0.9,
        }}
      />
      {/* Web3 dynamic background with animated elements */}
      <div 
        className="absolute inset-0 z-0 bg-gradient-to-b from-indigo-950/80 via-night/90 to-purple-950/80 overflow-hidden"
        style={{ backdropFilter: 'brightness(0.7) contrast(1.1)' }}
      >
        {/* Optimización: Reducido de 15 a 8 partículas para mejor rendimiento - ahora estático */}
        <div className="absolute inset-0 pointer-events-none">
          {/* Partículas pre-calculadas fijas en lugar de generadas dinámicamente */}
          <div className="absolute rounded-full" style={{
            width: '3px', height: '3px',
            left: '25%', top: '30%',
            background: 'rgba(200, 190, 255, 0.5)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
          <div className="absolute rounded-full" style={{
            width: '5px', height: '5px',
            left: '65%', top: '20%',
            background: 'rgba(180, 210, 255, 0.4)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
          <div className="absolute rounded-full" style={{
            width: '2px', height: '2px',
            left: '80%', top: '55%',
            background: 'rgba(170, 200, 255, 0.5)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
          <div className="absolute rounded-full" style={{
            width: '4px', height: '4px',
            left: '35%', top: '75%',
            background: 'rgba(200, 170, 255, 0.4)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
          <div className="absolute rounded-full" style={{
            width: '3px', height: '3px',
            left: '15%', top: '65%',
            background: 'rgba(180, 180, 255, 0.5)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
          <div className="absolute rounded-full" style={{
            width: '2px', height: '2px',
            left: '45%', top: '40%',
            background: 'rgba(210, 180, 255, 0.4)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
          <div className="absolute rounded-full" style={{
            width: '4px', height: '4px',
            left: '55%', top: '85%',
            background: 'rgba(190, 190, 255, 0.5)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
          <div className="absolute rounded-full" style={{
            width: '3px', height: '3px',
            left: '90%', top: '15%',
            background: 'rgba(200, 200, 255, 0.4)',
            boxShadow: '0 0 3px rgba(255, 255, 255, 0.3)',
          }}/>
        </div>
        
        {/* Glowing orbs */}
        <motion.div 
          className="absolute w-[50%] h-[50%] rounded-full bg-gradient-to-r from-purple-800/10 to-indigo-800/5"
          style={{ top: '15%', left: '-15%' }}
          animate={{
            scale: [1, 1.1, 1],
            opacity: [0.2, 0.4, 0.2],
          }}
          transition={{
            duration: 15,
            repeat: Infinity,
            ease: "easeInOut"
          }}
        />
        <motion.div 
          className="absolute w-[40%] h-[40%] rounded-full bg-gradient-to-r from-indigo-800/10 to-purple-800/5"
          style={{ bottom: '10%', right: '-10%' }}
          animate={{
            scale: [1, 1.2, 1],
            opacity: [0.1, 0.3, 0.1],
          }}
          transition={{
            duration: 18,
            repeat: Infinity,
            ease: "easeInOut",
            delay: 2
          }}
        />
        
        {/* Reemplazo de constelaciones: Líneas estáticas para mejor rendimiento */}
        <svg className="absolute inset-0 w-full h-full opacity-15">
          {/* Líneas pre-definidas en lugar de generadas dinámicamente */}
          <line
            x1="20%"
            y1="30%"
            x2="80%"
            y2="70%"
            stroke="rgba(147, 197, 253, 0.25)"
            strokeWidth="0.4"
          />
          <line
            x1="70%"
            y1="20%"
            x2="30%"
            y2="80%"
            stroke="rgba(147, 197, 253, 0.2)"
            strokeWidth="0.3"
          />
          <line
            x1="40%"
            y1="25%"
            x2="60%"
            y2="75%"
            stroke="rgba(147, 197, 253, 0.15)"
            strokeWidth="0.25"
          />
        </svg>
        
        {/* Hexágonos estáticos - para mejorar rendimiento removimos las animaciones */}
        <svg className="absolute inset-0 w-full h-full opacity-10" viewBox="0 0 100 100" preserveAspectRatio="none">
          {/* Usamos elementos estáticos pre-calculados en lugar de generar con map */}
          <path
            d="M25,15 L35,10 L45,15 L45,25 L35,30 L25,25 Z"
            stroke="rgba(103, 232, 249, 0.2)"
            strokeWidth="0.3"
            fill="none"
          />
          <path
            d="M40,22 L50,17 L60,22 L60,32 L50,37 L40,32 Z"
            stroke="rgba(103, 232, 249, 0.15)"
            strokeWidth="0.3"
            fill="none"
          />
        </svg>
        
        {/* Animated gradient overlay */}
        <motion.div 
          className="absolute inset-0 bg-gradient-to-br from-celestial/5 via-transparent to-spiritual/5"
          animate={{
            opacity: [0.3, 0.5, 0.3],
          }}
          transition={{
            duration: 8,
            repeat: Infinity,
            ease: "easeInOut"
          }}
        />
      </div>
      <div className="container mx-auto px-3 xs:px-4 sm:px-6 relative z-10 text-moon">
        <motion.div
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6 }}
        >
          <h2 className="font-playfair text-xl xs:text-2xl sm:text-3xl md:text-4xl text-center mb-3 xs:mb-4 sm:mb-6">
            Lectura de <span className="text-celestial">Tarot</span>
          </h2>
          <p className="text-center max-w-2xl mx-auto mb-2 xs:mb-3 sm:mb-4 text-sm xs:text-base sm:text-lg px-2 xs:px-3">
            Descubre los mensajes que las cartas tienen para ti con nuestro tarot virtual potenciado por IA
          </p>
          <div className="text-center max-w-2xl mx-auto mb-3 xs:mb-4 sm:mb-6 text-spiritual text-xs xs:text-sm sm:text-base px-2">
            <Badge variant="outline" className="mr-1 xs:mr-2 text-2xs xs:text-xs sm:text-sm">Arcanos Mayores</Badge>
            <span>Lectura basada en los 22 Arcanos Mayores del Tarot</span>
          </div>
          
          <div className="flex justify-center mb-3 xs:mb-4 sm:mb-6">
            <Badge variant="outline" className="text-2xs xs:text-xs sm:text-sm py-0.5 xs:py-1 px-1.5 xs:px-2 sm:px-3 border-celestial/50 text-celestial">
              <Sparkles className="mr-1 sm:mr-2 h-2.5 xs:h-3 sm:h-3.5 w-2.5 xs:w-3 sm:w-3.5" />
              Selecciona 3 cartas para tu lectura
            </Badge>
          </div>
          
          {/* Información de límite mensual para usuarios básicos */}
          {!isPremium && user && (
            <div className="bg-blue-600/40 border border-blue-400 rounded-xl p-4 mb-8 relative overflow-hidden max-w-2xl mx-auto backdrop-blur-sm">
              <div className="flex items-center mb-2">
                <Clock className="text-[#C098FF] mr-2" size={14} />
                <p className="text-[#E2D1FF]/90 text-sm">Límite mensual para usuarios Básicos:</p>
              </div>
              <div className="flex justify-between items-center">
                <p className="text-lg font-playfair text-[#C098FF]">
                  {readingsAvailable === -1 ? (
                    <span>Cargando lecturas disponibles...</span>
                  ) : (
                    <span>
                      {readingsAvailable} {readingsAvailable === 1 ? 'lectura disponible' : 'lecturas disponibles'} este mes
                    </span>
                  )}
                </p>
                {readingsAvailable <= 0 ? (
                  <Badge variant="outline" className="border-[#FF98F6]/50 text-[#FF98F6] text-xs py-0.5 px-2 whitespace-nowrap">
                    Límite alcanzado
                  </Badge>
                ) : (
                  <Badge variant="outline" className="border-[#C098FF]/50 text-[#C098FF] text-xs py-0.5 px-2 whitespace-nowrap">
                    {readingsAvailable} {readingsAvailable === 1 ? 'restante' : 'restantes'}
                  </Badge>
                )}
              </div>
              {/* Mostrar datos de diagnóstico para ayudar a depurar */}
              {readingsAvailableData && (
                <div className="text-[#E2D1FF]/70 text-xs mt-1 mb-1">
                  <Clock className="inline-block text-[#C098FF] mr-1" size={10} />
                  Mes: {readingsAvailableData.month || 'N/A'} | 
                  Usadas: {readingsAvailableData.used ?? 'N/A'} | 
                  Límite: {readingsAvailableData.limit ?? 'N/A'}
                </div>
              )}
              <p className="text-[#E2D1FF]/70 text-xs mt-2">
                <Sparkles className="inline-block text-[#C098FF] mr-1" size={10} />
                Actualiza a Premium para lecturas de tarot ilimitadas y más detalladas
              </p>
            </div>
          )}
          

        </motion.div>
        
        {/* Input para la pregunta (solo usuarios premium) */}
        {isPremium && (
          <div className="max-w-xl mx-auto mb-8 sm:mb-12">
            <div className="relative">
              <input
                type="text"
                placeholder="Escribe tu pregunta para la lectura (opcional)"
                value={readingQuestion}
                onChange={(e) => setReadingQuestion(e.target.value)}
                className="w-full p-2.5 sm:p-3 rounded-lg bg-white border border-spiritual/30 text-black focus:border-celestial outline-none transition-colors text-sm sm:text-base"
                maxLength={150}
              />
              <div className="absolute right-3 top-2.5 text-moon/50 text-xs sm:text-sm">
                {readingQuestion.length}/150
              </div>
            </div>
            <p className="text-xs sm:text-sm text-moon/70 mt-2">
              <Info className="inline-block mr-1" size={12} />
              Formular una pregunta específica ayuda a obtener una interpretación más precisa
            </p>
          </div>
        )}
        
        <div className="relative min-h-[320px] xs:min-h-[380px] sm:min-h-[450px] md:min-h-[550px] lg:min-h-[650px] flex flex-col items-center justify-center">
          <div className="w-full px-1 xs:px-2 sm:px-4 md:px-8 py-4 xs:py-6 sm:py-8">
            <div className="flex flex-row justify-center items-center gap-1 xs:gap-2 sm:gap-4 md:gap-6 lg:gap-8">
              {availableCards.map((card, index) => (
                <div key={index} className="relative">
                  <TarotCard 
                    onClick={() => selectCard(index)}
                    isRevealed={revealedCards[index]}
                    isInverted={invertedCards[index]}
                    frontImage={card.image} 
                    backImage={cardBackImage}
                    cardName={revealedCards[index] ? card.name : undefined}
                    disabled={isPending || selectedCards.length >= 3 || showResults || 
                            (!isPremium && readingsAvailable <= 0 && selectedCards.length === 0) || 
                            isPreviousReading}
                    size="responsive" // Haciendo tarjetas responsivas
                  />
                  {/* Hacemos que las cartas reveladas sean clickeables - botón optimizado para móvil */}
                  {revealedCards[index] && (
                    <div 
                      className="absolute inset-0 cursor-pointer"
                      onClick={() => viewCardDetails(card, invertedCards[index])}
                    >
                      <div className="absolute inset-0 bg-celestial/5 hover:bg-celestial/10 transition-colors rounded-lg opacity-0 hover:opacity-100">
                        <div className="absolute inset-0 flex items-center justify-center">
                          <div className="bg-night/80 p-0.5 xs:p-1 rounded-full">
                            <Eye className="h-3 w-3 xs:h-4 xs:w-4 sm:h-5 sm:w-5 text-celestial" />
                          </div>
                        </div>
                      </div>
                    </div>
                  )}
                </div>
              ))}
            </div>
          </div>
          
          <div className="text-center mt-8 sm:mt-10 md:mt-14">
            <p className="italic text-moon/80 mb-3 sm:mb-5 text-sm sm:text-base">
              {selectedCards.length === 0 ? "Selecciona tres cartas para tu lectura" : 
               selectedCards.length < 3 ? `Has seleccionado ${selectedCards.length} de 3 cartas` :
               "¡Lectura completa!"}
            </p>
            
            <div className="flex flex-wrap justify-center gap-2 sm:gap-3 mb-3 sm:mb-4">
              {user && tarotReadingHistory && Array.isArray(tarotReadingHistory) && tarotReadingHistory.length > 0 ? (
                <Button 
                  onClick={showLastReading}
                  className="relative overflow-hidden bg-celestial hover:bg-celestial/90 text-night text-xs sm:text-sm py-1.5 sm:py-2 h-auto group"
                  disabled={isPending || isPreviousReading}
                  style={{
                    clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)"
                  }}
                >
                  <motion.div
                    className="absolute inset-0 bg-gradient-to-r from-spiritual/20 to-celestial/20"
                    animate={{
                      x: ["100%", "-100%"]
                    }}
                    transition={{
                      duration: 2,
                      repeat: Infinity,
                      ease: "linear"
                    }}
                  />
                  <div className="relative flex items-center justify-center">
                    <Eye className="mr-1.5 h-3 sm:h-3.5 w-3 sm:w-3.5" />
                    <span className="group-hover:scale-105 transition-transform">Ver Última Lectura</span>
                  </div>
                </Button>
              ) : null}
            </div>
            
            <Button 
              onClick={prepareNewReading}
              className="relative overflow-hidden bg-spiritual hover:bg-spiritual/90 text-moon text-sm sm:text-base py-2 sm:py-3 h-auto group"
              disabled={isPending || selectedCards.length > 0 && selectedCards.length < 3}
              style={{
                clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)"
              }}
            >
              <motion.div
                className="absolute inset-0 bg-gradient-to-r from-celestial/20 to-spiritual/20"
                animate={{
                  x: ["100%", "-100%"]
                }}
                transition={{
                  duration: 2,
                  repeat: Infinity,
                  ease: "linear"
                }}
              />
              <div className="relative flex items-center justify-center">
                <RefreshCw className="mr-2 h-3.5 sm:h-4 w-3.5 sm:w-4 group-hover:rotate-180 transition-transform duration-500" />
                <span className="group-hover:scale-105 transition-transform">Preparar Nueva Lectura</span>
              </div>
              <motion.div
                className="absolute -inset-0.5 rounded-md opacity-0 group-hover:opacity-100 bg-spiritual"
                style={{
                  clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)"
                }}
                animate={{
                  scale: [1, 1.03, 1]
                }}
                transition={{
                  duration: 2,
                  repeat: Infinity,
                  ease: "easeInOut"
                }}
                initial={{
                  opacity: 0,
                  scale: 1
                }}
              />
            </Button>
          </div>
        </div>
      </div>
      
      {/* Modal de resultados */}
      <Dialog open={showResults} onOpenChange={setShowResults}>
        <DialogContent 
          className="bg-night border-spiritual/50 max-h-[90vh] overflow-auto w-[95vw] xs:w-[90vw] sm:max-w-xl md:max-w-2xl lg:max-w-3xl p-3 xs:p-4 sm:p-6 mx-auto"
        >
          <DialogHeader className="pb-2 sm:pb-3">
            <DialogTitle className="font-playfair text-lg sm:text-xl text-center">
              Tu Lectura de <span className="text-celestial">Tarot</span>
            </DialogTitle>
            <DialogDescription className="text-center text-moon/70 text-xs sm:text-sm">
              {readingQuestion ? (
                <span>Pregunta: "{readingQuestion}"</span>
              ) : (
                <span>{new Date().toLocaleDateString('es-ES', { day: 'numeric', month: 'long', year: 'numeric' })}</span>
              )}
            </DialogDescription>
          </DialogHeader>
          
          {/* Grid de distribución optimizado para móvil y todos los tamaños */}
          <div className="grid grid-cols-3 gap-0.5 xs:gap-1 sm:gap-2 my-1 xs:my-2 sm:my-3 w-full">
            {selectedCards.map((card, index) => (
              <div key={index} className="flex flex-col items-center justify-start">
                <h3 className="text-celestial font-playfair mb-0.5 xs:mb-1 text-[0.65rem] xs:text-xs sm:text-sm text-center min-h-[1.5rem] xs:min-h-[1.8rem] sm:min-h-[2rem] flex items-center justify-center">
                  <span className="truncate max-w-[80px] xs:max-w-[100px] sm:max-w-full">{card.name}</span>
                  {selectedInvertedCards[index] && <span className="text-spiritual ml-0.5 xs:ml-1 text-[0.6rem] xs:text-xs">(Inv)</span>}
                </h3>
                <div 
                  className="aspect-[2/3] w-12 xs:w-14 sm:w-16 md:w-20 rounded-md border border-celestial/30 overflow-hidden golden-glow"
                >
                  <img 
                    src={card.image} 
                    alt={card.name}
                    className={cn(
                      "w-full h-full object-contain",
                      selectedInvertedCards[index] && "rotate-180"
                    )}
                    style={{ maxWidth: "100%", imageRendering: "auto" }}
                  />
                </div>
                <p className="text-moon/70 text-[0.65rem] xs:text-xs mt-0.5 xs:mt-1">{index + 1}</p>
              </div>
            ))}
          </div>
          
          <ScrollArea className="max-h-[40vh] sm:max-h-[45vh] md:max-h-[50vh]">
            <div className="p-2 sm:p-3">
              {isPending ? (
                <div className="flex items-center justify-center py-4 sm:py-6">
                  <span className="animate-spin rounded-full h-4 w-4 sm:h-5 sm:w-5 border-t-2 border-b-2 border-celestial mr-2"></span>
                  <span>Interpretando tu lectura...</span>
                </div>
              ) : readingResult?.interpretation ? (
                <MarkdownRenderer 
                  markdown={readingResult.interpretation} 
                  className="text-xs sm:text-sm md:text-base"
                />
              ) : (
                <p className="text-xs sm:text-sm md:text-base whitespace-pre-line">
                  Las cartas revelan un momento de transformación en tu vida. La primera carta sugiere que estás en un período de reflexión donde necesitas confiar en tu intuición. La segunda carta indica una oportunidad que se presentará pronto, mientras que la tercera sugiere que deberás tomar una decisión importante en el futuro cercano. Es un buen momento para la introspección y para planificar los próximos pasos.
                </p>
              )}
              
              {!isPremium && (
                <div className="mt-3 sm:mt-4 p-2 sm:p-3 bg-spiritual/10 border border-spiritual/30 rounded-lg">
                  <p className="flex items-center text-celestial mb-1 text-xs sm:text-sm">
                    <Sparkles className="mr-1 sm:mr-1.5" size={14} />
                    <span className="font-playfair">Mejora tu experiencia</span>
                  </p>
                  <p className="text-moon/80 text-2xs sm:text-xs">
                    Con el plan Premium obtendrás interpretaciones más detalladas, podrás hacer preguntas específicas para tus lecturas y tendrás acceso ilimitado a todas las funciones.
                  </p>
                </div>
              )}
            </div>
          </ScrollArea>
          
          <DialogFooter className="sm:justify-center mt-3 sm:mt-4 pb-1">
            <Button 
              onClick={() => setShowResults(false)}
              className="relative overflow-hidden bg-spiritual hover:bg-spiritual/90 text-moon text-xs sm:text-sm h-auto py-1.5 sm:py-2 px-5 sm:px-6 border border-celestial/40 hover:border-celestial transition-colors group"
              style={{
                clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)"
              }}
            >
              <motion.div
                className="absolute inset-0 bg-gradient-to-r from-celestial/20 to-spiritual/20"
                animate={{
                  x: ["100%", "-100%"]
                }}
                transition={{
                  duration: 2,
                  repeat: Infinity,
                  ease: "linear"
                }}
              />
              <div className="relative flex items-center justify-center">
                <span className="group-hover:scale-105 transition-transform">✧ Cerrar ✧</span>
              </div>
            </Button>
          </DialogFooter>
        </DialogContent>
      </Dialog>
      
      {/* Modal de detalles de carta - Optimizado para móvil */}
      <Dialog open={showCardDetails} onOpenChange={setShowCardDetails}>
        <DialogContent className="bg-night border-spiritual/50 w-[95vw] xs:w-[90vw] sm:max-w-md md:max-w-lg p-2 xs:p-3 sm:p-4 md:p-6 mx-auto max-h-[90vh] overflow-y-auto">
          <DialogHeader className="pb-1 xs:pb-2">
            <DialogTitle className="font-playfair text-base xs:text-lg sm:text-xl text-center">
              <span className="text-celestial">
                {selectedCardDetails?.name}
                {isCardInverted && <span className="text-spiritual text-xs xs:text-sm sm:text-base"> (Invertida)</span>}
              </span>
            </DialogTitle>
            <DialogDescription className="text-center text-moon/70 text-[0.65rem] xs:text-xs sm:text-sm">
              Arcano Mayor
            </DialogDescription>
          </DialogHeader>
          
          <div className="flex flex-col items-center my-2 xs:my-3 sm:my-4">
            {/* Imagen más pequeña en móvil para dejar espacio */}
            <div className="aspect-[2/3] w-28 xs:w-32 sm:w-40 md:w-48 rounded-md border border-celestial/30 overflow-hidden golden-glow">
              <img 
                src={selectedCardDetails?.image} 
                alt={selectedCardDetails?.name}
                className={cn(
                  "w-full h-full object-contain",
                  isCardInverted && "rotate-180"
                )}
              />
            </div>
            
            <div className="mt-2 xs:mt-3 sm:mt-4 space-y-1 xs:space-y-1.5 sm:space-y-2 text-center">
              <p className="text-celestial text-xs xs:text-sm sm:text-base">
                <span className="text-spiritual mr-1 xs:mr-1.5">Número:</span> 
                {selectedCardDetails?.id}
              </p>
              <p className="text-celestial text-xs xs:text-sm sm:text-base">
                <span className="text-spiritual mr-1 xs:mr-1.5">Arcano:</span> 
                {"Mayor"}
              </p>
              <p className="text-celestial text-xs xs:text-sm sm:text-base">
                <span className="text-spiritual mr-1 xs:mr-1.5">Tipo:</span> 
                {isCardInverted ? "Invertida" : "Derecha"}
              </p>
            </div>
            
            <ScrollArea className="mt-2 xs:mt-3 sm:mt-4 max-h-32 xs:max-h-40 sm:max-h-48 md:max-h-56 w-full">
              <p className="text-[0.65rem] xs:text-xs sm:text-sm text-moon leading-relaxed">
                {selectedCardDetails?.description || "No hay descripción disponible para esta carta."}
              </p>
              
              <div className="mt-3 xs:mt-4 sm:mt-5">
                <h4 className="text-celestial font-playfair text-xs xs:text-sm sm:text-base mb-1 xs:mb-1.5">Palabras clave:</h4>
                <div className="flex flex-wrap gap-1 xs:gap-1.5">
                  {selectedCardDetails?.keywords?.map((keyword, i) => (
                    <Badge 
                      key={i} 
                      variant="outline" 
                      className="border-spiritual/40 text-spiritual text-[0.6rem] xs:text-2xs sm:text-xs py-0 xs:py-0.5"
                    >
                      {keyword}
                    </Badge>
                  ))}
                </div>
              </div>
              
              {isCardInverted && (
                <div className="mt-3 xs:mt-4 sm:mt-5">
                  <h4 className="text-spiritual font-playfair text-xs xs:text-sm sm:text-base mb-1 xs:mb-1.5">Significado invertido:</h4>
                  <p className="text-[0.65rem] xs:text-xs sm:text-sm text-moon/90 leading-relaxed">
                    {selectedCardDetails?.meaning?.reversed || "No hay información sobre el significado invertido."}
                  </p>
                </div>
              )}
            </ScrollArea>
          </div>
          
          <DialogFooter className="mt-2 xs:mt-3">
            <Button 
              onClick={() => setShowCardDetails(false)}
              className="w-full relative overflow-hidden bg-spiritual hover:bg-spiritual/90 text-moon text-[0.65rem] xs:text-xs sm:text-sm py-1 xs:py-1.5 sm:py-2 h-auto"
              style={{
                clipPath: "polygon(8% 0%, 92% 0%, 100% 50%, 92% 100%, 8% 100%, 0% 50%)"
              }}
            >
              <span className="relative z-10">✧ Cerrar ✧</span>
              <motion.div
                className="absolute inset-0 bg-gradient-to-r from-celestial/20 to-spiritual/20"
                animate={{
                  x: ["100%", "-100%"]
                }}
                transition={{
                  duration: 1.5,
                  repeat: Infinity,
                  ease: "linear"
                }}
              />
            </Button>
          </DialogFooter>
        </DialogContent>
      </Dialog>
      
      {/* Modal de lectura de tarot (pop-up) */}
      <Dialog 
        open={showReadingDialog} 
        onOpenChange={(open) => {
          setShowReadingDialog(open);
          if (!open && isPreviousReading) {
            setIsPreviousReading(false);
            prepareNewReading();
          }
        }}>
        <DialogContent 
          className="bg-night border-spiritual/50 max-h-[95vh] overflow-y-auto w-[95vw] xs:w-[90vw] sm:max-w-xl md:max-w-2xl lg:max-w-3xl p-2 xs:p-3 sm:p-4 md:p-6 mx-auto"
        >
          <DialogHeader className="pb-1 xs:pb-2 sm:pb-3">
            <DialogTitle className="font-playfair text-base xs:text-lg sm:text-xl md:text-2xl text-center relative">
              <motion.div 
                className="absolute w-full h-0.5 bg-gradient-to-r from-transparent via-celestial/50 to-transparent bottom-0 left-0"
                initial={{ scaleX: 0 }}
                animate={{ scaleX: 1 }}
                transition={{ duration: 1.2, ease: "easeOut" }}
              />
              <span className="text-celestial inline-block animate-pulse">✧</span> 
              <span className="relative">
                {isPreviousReading ? "Última Lectura de Tarot" : "Tu Lectura de Tarot"}
                <motion.span 
                  className="absolute -bottom-1 left-0 w-full h-0.5 bg-gradient-to-r from-transparent via-spiritual/30 to-transparent"
                  initial={{ scaleX: 0, opacity: 0 }}
                  animate={{ scaleX: 1, opacity: 1 }}
                  transition={{ duration: 1.5, delay: 0.3 }}
                />
              </span> 
              <span className="text-celestial inline-block animate-pulse">✧</span>
            </DialogTitle>
            <DialogDescription className="text-center text-moon/70 text-[0.65rem] xs:text-xs sm:text-sm mt-2 xs:mt-3 px-1">
              {readingQuestion ? (
                <span className="inline-flex items-center justify-center gap-1">
                  <HelpCircle size={12} className="text-spiritual/70" />
                  <span className="line-clamp-2">Pregunta: "{readingQuestion}"</span>
                </span>
              ) : (
                <span className="inline-flex items-center justify-center gap-1">
                  <Calendar size={12} className="text-spiritual/70" />
                  <span>Lectura general - {isPreviousReading && readingResult?.date ? 
                    new Date(readingResult.date).toLocaleDateString('es-ES', { day: 'numeric', month: 'long', year: 'numeric' }) : 
                    new Date().toLocaleDateString('es-ES', { day: 'numeric', month: 'long', year: 'numeric' })}
                  </span>
                </span>
              )}
            </DialogDescription>
          </DialogHeader>
          
          {/* Grid de distribución uniforme para las cartas */}
          {selectedCards.length > 0 && (
            <div className="grid grid-cols-3 gap-0.5 xs:gap-1 sm:gap-2 my-1 xs:my-2 sm:my-4 w-full">
              {selectedCards.map((card, index) => (
                <div key={index} className="flex flex-col items-center justify-start">
                  <div className="mb-0.5 xs:mb-1 sm:mb-2 text-center">
                    <span className="inline-block px-1 xs:px-1.5 sm:px-2 py-0.5 rounded-full bg-celestial/20 text-celestial text-[0.6rem] xs:text-2xs sm:text-xs whitespace-nowrap">
                      {index === 0 ? "Pasado" : index === 1 ? "Presente" : "Futuro"}
                    </span>
                  </div>
                  <h3 className="text-celestial font-playfair mb-0.5 xs:mb-1 sm:mb-2 text-[0.6rem] xs:text-xs sm:text-sm text-center min-h-[1.5rem] xs:min-h-[1.8rem] sm:min-h-[2rem] flex items-center justify-center px-0.5">
                    <span className="truncate max-w-[80px] xs:max-w-[100px] sm:max-w-full">
                      {card.name}
                      {selectedInvertedCards[index] && <span className="text-spiritual ml-0.5 xs:ml-1 text-[0.6rem] xs:text-xs">(Inv)</span>}
                    </span>
                  </h3>
                  <div 
                    className="aspect-[2/3] w-14 xs:w-16 sm:w-20 md:w-24 lg:w-28 rounded-md border border-celestial/30 overflow-hidden golden-glow"
                  >
                    <img 
                      src={card.image} 
                      alt={card.name}
                      className={cn(
                        "w-full h-full object-contain",
                        selectedInvertedCards[index] && "rotate-180"
                      )}
                      style={{ maxWidth: "100%", imageRendering: "auto" }}
                    />
                  </div>
                </div>
              ))}
            </div>
          )}
          
          <div className="ai-content-box relative py-3 px-2 xs:px-3 sm:px-4">
              {/* Decoración visual - orbes místicos en las esquinas */}
              <div className="absolute -top-1 -left-1 w-3 h-3 rounded-full bg-spiritual/10 animate-pulse"></div>
              <div className="absolute -top-1 -right-1 w-3 h-3 rounded-full bg-celestial/10 animate-pulse"></div>
              <div className="absolute -bottom-1 -left-1 w-3 h-3 rounded-full bg-celestial/10 animate-pulse"></div>
              <div className="absolute -bottom-1 -right-1 w-3 h-3 rounded-full bg-spiritual/10 animate-pulse"></div>
              
              {/* Título decorativo */}
              <div className="text-center mb-3 hidden sm:block">
                <div className="text-sm font-playfair gradient-text">
                  ✧ Mensaje de las Cartas ✧
                </div>
                <div className="section-divider mt-1"></div>
              </div>
              
              {isPending ? (
                <div className="flex flex-col items-center justify-center py-3 xs:py-4 sm:py-6">
                  <div className="animate-spin rounded-full h-4 w-4 xs:h-5 xs:w-5 sm:h-7 sm:w-7 border-t-2 border-b-2 border-celestial mb-2 sm:mb-3"></div>
                  <p className="text-moon/90 text-[0.65rem] xs:text-xs sm:text-sm">
                    Interpretando las cartas con Runalya AI...
                  </p>
                </div>
              ) : readingResult?.interpretation ? (
                <div className="space-y-2">
                  <MarkdownRenderer 
                    markdown={readingResult.interpretation}
                    className="text-[0.65rem] xs:text-xs sm:text-sm md:text-base leading-relaxed text-moon"
                  />
                </div>
              ) : (
                <p className="text-[0.65rem] xs:text-xs sm:text-sm md:text-base whitespace-pre-line leading-relaxed text-moon">
                  Interpretando tu lectura...
                </p>
              )}
            </div>
          
          <DialogFooter className="justify-center mt-2 xs:mt-3 sm:mt-4 pb-0 xs:pb-1 flex flex-wrap gap-1 xs:gap-2">
            <div className="flex flex-wrap justify-center w-full gap-2">
              {isPreviousReading && (
                <Button 
                  onClick={() => {
                    setShowReadingDialog(false);
                    setIsPreviousReading(false);
                    prepareNewReading(); // Preparar nuevas cartas para interacción
                  }}
                  className="relative overflow-hidden bg-spiritual hover:bg-spiritual/90 text-moon text-[0.7rem] xs:text-xs sm:text-sm h-auto py-1.5 xs:py-2 sm:py-2.5 px-4 xs:px-5 sm:px-6 group min-w-[90px] max-w-[130px]"
                  style={{
                    clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)"
                  }}
                >
                  <motion.div
                    className="absolute inset-0 bg-gradient-to-r from-spiritual/20 to-celestial/20"
                    animate={{
                      x: ["100%", "-100%"]
                    }}
                    transition={{
                      duration: 2,
                      repeat: Infinity,
                      ease: "linear"
                    }}
                  />
                  <div className="relative flex items-center justify-center">
                    <span className="group-hover:scale-105 transition-transform">Cerrar</span>
                  </div>
                </Button>
              )}
              
              <Button 
                onClick={() => {
                  setShowReadingDialog(false);
                  setIsPreviousReading(false);
                  prepareNewReading();
                }}
                className="relative overflow-hidden bg-celestial hover:bg-celestial/90 text-night text-[0.7rem] xs:text-xs sm:text-sm h-auto py-1.5 xs:py-2 sm:py-2.5 px-4 xs:px-5 sm:px-6 group min-w-[130px] max-w-[180px]"
                style={{
                  clipPath: "polygon(10% 0%, 90% 0%, 100% 50%, 90% 100%, 10% 100%, 0% 50%)"
                }}
              >
                <motion.div
                  className="absolute inset-0 bg-gradient-to-r from-spiritual/20 to-celestial/20"
                  animate={{
                    x: ["100%", "-100%"]
                  }}
                  transition={{
                    duration: 2,
                    repeat: Infinity,
                    ease: "linear"
                  }}
                />
                <div className="relative flex items-center justify-center">
                  <span className="group-hover:scale-105 transition-transform whitespace-nowrap">✧ Nueva Lectura ✧</span>
                </div>
              </Button>
            </div>
          </DialogFooter>
        </DialogContent>
      </Dialog>
      
      <AuthModal isOpen={showAuthModal} onClose={() => setShowAuthModal(false)} />
    </section>
  );
}